# Ubuntu Continuous Integration Engine
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from tastypie import fields
from tastypie.resources import ModelResource
from ticket.models import Ticket, SubTicket, SourcePackageUpload, Artifact

from people.api import PersonResource
from project.api import SourcePackageResource


class TicketResource(ModelResource):
    owner = fields.ToOneField(PersonResource, 'owner', full=True)

    class Meta:
        queryset = Ticket.objects.all()
        allowed_methods = ['get']


class SourcePackageUploadResource(ModelResource):
    sourcepackage = fields.ToOneField(SourcePackageResource, 'sourcepackage',
                                      full=True)

    class Meta:
        queryset = SourcePackageUpload.objects.all()
        allowed_methods = ['get']


class SubTicketResource(ModelResource):
    assignee = fields.ToOneField(PersonResource, 'assignee', full=True)
    ticket = fields.ToOneField(TicketResource, 'ticket', full=True)
    source_package_upload = fields.ToOneField(SourcePackageUploadResource,
                                              'source_package_upload',
                                              full=True)

    class Meta:
        queryset = SubTicket.objects.all()
        allowed_methods = ['get']


class ArtifactResource(ModelResource):
    ticket_component = fields.ToOneField(SubTicketResource, 'ticket_component',
                                         full=True)

    class Meta:
        queryset = Artifact.objects.all()
        allowed_methods = ['get']


class FullArtifactResource(ModelResource):

    class Meta:
        queryset = Artifact.objects.all()
        allowed_methods = ['get']


class FullSubTicketResource(ModelResource):
    assignee = fields.ToOneField(PersonResource, 'assignee', full=True)
    source_package_upload = fields.ToOneField(SourcePackageUploadResource,
                                              'source_package_upload',
                                              full=True)
    artifact = fields.ToManyField(FullArtifactResource, 'artifact_set',
                                  full=True)

    class Meta:
        queryset = SubTicket.objects.all()
        allowed_methods = ['get']


class FullTicketResource(ModelResource):
    owner = fields.ToOneField(PersonResource, 'owner', full=True)
    subticket = fields.ToManyField(FullSubTicketResource, 'subticket_set',
                                   full=True)

    class Meta:
        queryset = Ticket.objects.all()
        allowed_methods = ['get']
